update method

void update(
  1. void updater(
    1. T state
    )
)

Executes to provided updater function to update a part of the state. This function is useful for complex mutable state objects. After the updater function was executed, the component and its children will be rerendered using the new state.

Implementation

void update(void Function(T state) updater) {
  updater(_value as T);
  _valueChanged = true;
  final location = _instance.rootLocation.find(_locationId);
  if (location != null) {
    _renderInstance(_instance, nodeLocation: location);
  }
  //throw StateError('location $_locationId not found!');
}