value property
T
get
value
Returns the actual state object.
Implementation
T get value => _value as T;
set
value
(T value)
Sets a new state. After the new state is applied, the component and its children will be rerendered using the new state.
Implementation
set value(T value) {
_value = value;
_valueChanged = true;
final location = _instance.rootLocation.find(_locationId);
if (location != null) {
_renderInstance(_instance, nodeLocation: location);
}
//throw StateError('location $_locationId not found!');
}